import request from '@/utils/request'

const personApi = {
  addOrUpdate: 'person/addOrUpdate',
  del: 'person/del',
	get: 'person/get',
  page: 'person/pageList',
	transferOrg: 'person/transferOrg',
	quit: 'person/quit',
	resetPwd: 'person/resetPwd',
	setAdmin: 'person/setAdmin',
  changeLogPage: '/person/changeLog/pageList'
}

export function personAddOrUpdate (params) {
  return request({
    url: personApi.addOrUpdate,
    method: 'post',
    data: params
  })
}
export function personGet (params) {
  return request({
    url: personApi.get,
    method: 'get',
    params: params
  })
}
export function personDel (params) {
  return request({
    url: personApi.del,
    method: 'post',
    params: params
  })
}
export function personPage (params) {
  return request({
    url: personApi.page,
    method: 'get',
    params: params
  })
}
export function personTransferOrg (params) {
  return request({
    url: personApi.transferOrg,
    method: 'get',
    params: params
  })
}
export function personQuit (params) {
  return request({
    url: personApi.quit,
    method: 'get',
    params: params
  })
}
export function personResetPwd (params) {
  return request({
    url: personApi.resetPwd,
    method: 'get',
    params: params
  })
}
export function personSetAdmin (params) {
  return request({
    url: personApi.setAdmin,
    method: 'get',
    params: params
  })
}
export function personChangeLogPage (params) {
  return request({
    url: personApi.changeLogPage,
    method: 'get',
    params: params
  })
}
